==> seedsui-react-2.7.9.tgz: package/es/Popover/Popover.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var Popover = (_temp = _class = function (_Component) {
  _inherits(Popover, _Component);

  function Popover(props) {
    _classCallCheck(this, Popover);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {};

    _this.onClick = function (e) {
      e.stopPropagation();
    };

    return _this;
  }
  // 点击popover主体


  Popover.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        animation = _props.animation,
        onClick = _props.onClick,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['portal', 'show', 'animation', 'onClick', 'maskAttribute', 'children']);

    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, maskAttribute, { className: 'mask popover-mask' + (maskAttribute.className ? ' ' + maskAttribute.className : '') + (show ? ' active' : '') }),
      React.createElement(
        'div',
        _extends({}, others, { className: 'popover' + (others.className ? ' ' + others.className : '') + (show ? ' active' : ''), 'data-animation': animation, onClick: onClick ? onClick : this.onClick }),
        children && children
      )
    ), portal || document.getElementById('root') || document.body);
  };

  return Popover;
}(Component), _class.defaultProps = {
  animation: 'zoom'
}, _temp);
export { Popover as default };
Popover.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  show: PropTypes.bool,
  animation: PropTypes.string, // slideLeft | slideRight | slideUp | slideDown | zoom | fade
  onClick: PropTypes.func,
  maskAttribute: PropTypes.object,
  children: PropTypes.node
} : {};

==> seedsui-react-3.7.9.tgz: package/es/Popover/Popover.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var Popover = (_temp = _class = function (_Component) {
  _inherits(Popover, _Component);

  function Popover(props) {
    _classCallCheck(this, Popover);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {};

    _this.onClick = function (e) {
      e.stopPropagation();
    };

    return _this;
  }
  // 点击popover主体


  Popover.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        animation = _props.animation,
        duration = _props.duration,
        onClick = _props.onClick,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['portal', 'show', 'animation', 'duration', 'onClick', 'maskAttribute', 'children']);

    // 构建动画


    var animationClassName = '';
    if (animation !== 'none') {
      animationClassName = 'popup-animation';
    }

    // 动画时长
    var durationStyle = {};
    if (typeof duration === 'number') {
      durationStyle = {
        WebkitTransitionDuration: duration + 'ms'
      };
    }

    return createPortal(React.createElement(
      'div',
      _extends({
        ref: function ref(el) {
          _this2.$el = el;
        }
      }, maskAttribute, {
        className: 'mask popover-mask' + (maskAttribute.className ? ' ' + maskAttribute.className : '') + (show ? ' active' : ''),
        style: Object.assign({}, durationStyle, maskAttribute.style || {})
      }),
      React.createElement(
        'div',
        _extends({}, others, {
          className: 'popover' + (animationClassName ? ' ' + animationClassName : '') + (others.className ? ' ' + others.className : '') + (show ? ' active' : ''),
          style: Object.assign({}, durationStyle, others.style || {}),
          'data-animation': animation,
          onClick: onClick ? onClick : this.onClick
        }),
        children && children
      )
    ), portal || document.getElementById('root') || document.body);
  };

  return Popover;
}(Component), _class.defaultProps = {
  animation: 'zoom'
}, _temp);
export { Popover as default };
Popover.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  show: PropTypes.bool,
  animation: PropTypes.string, // slideLeft | slideRight | slideUp | slideDown | zoom | fade
  onClick: PropTypes.func,
  maskAttribute: PropTypes.object,
  children: PropTypes.node
} : {};
